#[cfg(feature = "ocr")]
pub(crate) mod ocr {
    use std::error::Error;
    use image::DynamicImage;
    use rusty_tesseract::{Args, Image};

    /**

    OEM 解释
     0 仅旧版引擎
     1 仅神经网络 LSTM 引擎
     2 个旧版 + LSTM 引擎
     3 默认，基于可用的内容


    PSM 解释 ：
     0 仅方向和脚本检测 (OSD)。
     1 使用 OSD 自动页面分割。
     2 自动页面分割，但没有 OSD 或 OCR。 （未实现）
     3 全自动页面分割，但无OSD。 （默认）
     4 假设有一列大小可变的文本。
     5 假设有一个统一的垂直对齐文本块。
     6 假设有一个统一的文本块。
     7 将图像视为单个文本行。
     8 将图像视为单个单词。
     9 将图像视为圆圈中的单个单词。
    10 将图像视为单个字符。
    11 稀疏文本。 查找尽可能多的文本（不按特定顺序排列）。
    12 带 OSD 的稀疏文本。
    13 原始线。 将图像视为单个文本行，

    */

    pub(crate) fn find_string_in_image(image: &DynamicImage, psm:i32) -> String {
        let img = Image::from_dynamic_image(image).expect("from image failed");
        let mut args = Args {
            lang: "chi_sim".to_string(),
            config_variables: Default::default(),
            dpi: Some(300),
            psm: Some(psm),
            oem: Some(3),
        };
        let output = rusty_tesseract::image_to_string(&img, &args).expect("image to string failed");
        return output;
    }


    pub(crate) fn find_text_in_image(key_words: &Vec<String>, image: &DynamicImage) -> bool {
        let img = Image::from_dynamic_image(image).expect("from image failed");
        let mut args = Args {
            lang: "chi_sim".to_string(),
            config_variables: Default::default(),
            dpi: Some(600),
            psm: Some(6),
            oem: Some(3),
        };
        let output = rusty_tesseract::image_to_string(&img, &args).expect("image to string failed");
        for word in key_words{
            if output.contains(word){
                return true;
            }
        }
        return false;
    }
}