#[cfg(feature = "pokemon")]
pub(crate) mod pokemon {
    pub enum PokeType {
        Normal,
        Fighting,
        Flying,
        Poison,
        Ground,
        Rock,
        Bug,
        Ghost,
        Steel,
        File,
        Water,
        Grass,
        Electric,
        Psychic,
        Ice,
        Dragon,
        Dark,
        Fairy,
    }

    pub struct Pokemon {
        pub(crate) dex: PokeDex,
        pub(crate) moves: Vec<MoveCategory>,
        pub(crate) lv: u32,
        pub(crate) stat: Stat,
        pub(crate) status: StatusChange,
        pub(crate) nature: Nature
    }

    pub struct PokeDex {
        pub(crate) no: u32,
        pub(crate) fir_type: PokeType,
        pub(crate) sec_type: Option<PokeType>,
        pub(crate) iv: Iv,
    }

    pub struct Iv {
        pub(crate) hp: u32,
        pub(crate) attack: u32,
        pub(crate) defense: u32,
        pub(crate) sp_atk: u32,
        pub(crate) sp_def: u32,
        pub(crate) speed: u32,
    }

    pub struct Ev {
        pub(crate) hp: u32,
        pub(crate) attack: u32,
        pub(crate) defense: u32,
        pub(crate) sp_atk: u32,
        pub(crate) sp_def: u32,
        pub(crate) speed: u32,
    }

    pub struct Stat {
        pub(crate) hp: u32,
        pub(crate) attack: u32,
        pub(crate) defense: u32,
        pub(crate) sp_atk: u32,
        pub(crate) sp_def: u32,
        pub(crate) speed: u32,
    }

    pub struct StatusChange {
        pub(crate) attack: i32,
        pub(crate) defense: i32,
        pub(crate) sp_atk: i32,
        pub(crate) sp_def: i32,
        pub(crate) speed: i32,
        pub(crate) accuracy: i32,
        pub(crate) evasion: i32,
    }

    pub enum MoveCategory {
        Physical,
        Special,
        Status,
    }

    pub struct Move {
        pub(crate) cat: MoveCategory,
        pub(crate) value: u32,
    }

    pub enum Nature {
        Hardy,
        Lonely,
        Brave,
        Adamant,
        Naughty,
        Bold,
        Docile,
        Relaxed,
        Impish,
        Lax,
        Timid,
        Hasty,
        Serious,
        Jolly,
        Naive,
        Modest,
        Mild,
        Quiet,
        Bashful,
        Rash,
        Calm,
        Gentle,
        Sassy,
        Careful,
        Quirky,
    }

    // impl Nature {
    //     pub fn influence(&self) -> (f32, f32, f32, f32, f32) {
    //         return match &self {
    //             Hardy => (0_f32, 0_f32, 0_f32, 0_f32, 0_f32),
    //             Lonely => (1.1_f32, 0.9_f32, 0_f32, 0_f32, 0_f32),
    //             Brave => (1.1_f32, 0_f32, 0_f32, 0_f32, 0.9_f32),
    //             Adamant => (1.1_f32, 0_f32, 0.9_f32, 0_f32, 0_f32),
    //             Naughty => (1.1_f32, 0_f32, 0_f32, 0.9_f32, 0_f32),
    //             Bold => (0.9_f32, 1.1_f32, 0_f32, 0_f32, 0_f32),
    //             Docile => (0_f32, 0_f32, 0_f32, 0_f32, 0_f32),
    //             Relaxed => (0_f32, 1.1_f32, 0_f32, 0_f32, 0.9_f32),
    //             Impish => (0_f32, 1.1_f32, 0.9_f32, 0_f32, 0_f32),
    //             Lax => (0_f32, 1.1_f32, 0_f32, 0.9_f32, 0_f32),
    //             Timid => (0.9_f32, 0_f32, 0_f32, 0_f32, 1.1_f32),
    //             Hasty => (0_f32, 0.9_f32, 0_f32, 0_f32, 1.1_f32),
    //             Serious => (0_f32, 0_f32, 0_f32, 0_f32, 0_f32),
    //             Jolly => (0_f32, 0_f32, 0.9_f32, 0_f32, 1.1_f32),
    //             Naive => (0_f32, 0_f32, 0_f32, 0.9_f32, 1.1_f32),
    //             Modest => (0.9_f32, 0_f32, 1.1_f32, 0_f32, 0_f32),
    //             Mild => (0_f32, 0.9_f32, 1.1_f32, 0_f32, 0_f32),
    //             Quiet => (0_f32, 0_f32, 1.1_f32, 0_f32, 0.9_f32),
    //             Bashful => (0_f32, 0_f32, 0_f32, 0_f32, 0_f32),
    //             Rash => (0_f32, 0_f32, 1.1_f32, 0.9_f32, 0_f32),
    //             Calm => (0.9_f32, 0_f32, 0_f32, 1.1_f32, 0_f32),
    //             Gentle => (0_f32, 0.9_f32, 0_f32, 1.1_f32, 0_f32),
    //             Sassy => (0_f32, 0_f32, 0_f32, 1.1_f32, 0.9_f32),
    //             Careful => (0_f32, 0_f32, 0.9_f32, 1.1_f32, 0_f32),
    //             Quirky => (0_f32, 0_f32, 0_f32, 0_f32, 0_f32),
    //         };
    //     }
    // }
}